@@ -33,13 +33,21 @@ env_exists <- function(...) {
     vapply(res, nzchar, logical(1))
 }
 
+# Fix username without domain
+fix_username <- function(x) {
+    if (!grepl("@", x, fixed = TRUE))
+        x <- paste0(x, "@gmail.com")
+    return(x)
+}
+
 #' @title Authorize the RGA package to the user's Google Analytics account using OAuth2.0
 #'
 #' @description \code{authorize()} function uses \code{\link[httr]{oauth2.0_token}} to obtain the OAuth tokens. Expired tokens will be refreshed automamaticly. If you have no \code{client.id} and \code{client.secret} the package provides predefined values.
 #'
+#' @param username character. Google username email address hint. If not set you will need choose an account for the authorization.
 #' @param client.id character. OAuth client ID. If you set the environment variable \env{RGA_CLIENT_ID} it is used.
 #' @param client.secret character. OAuth client secret. If you set the environment variable \env{RGA_CLIENT_SECRET} it is used.
-#' @param cache logical or character. \code{TRUE} means to cache using the default cache file \code{.oauth-httr}, \code{FALSE} means not to cache. A string means to use the specified path as the cache file.
+#' @param cache logical or character. \code{TRUE} means to cache using the default cache file \code{.oauth-httr}, \code{FALSE} means not to cache. A string means to use the specified path as the cache file. Otherwise will be used the \code{rga.cache} option value (\code{.ga-token.rds} by default). If \code{username} argument specified token will be cached in the \code{.username-token.rds} file.
 #' @param new.auth logical. Set \code{TRUE} to reauthorization with the same or different Google Analytics account.
 #'
 #' @details
@@ -48,6 +56,8 @@ env_exists <- function(...) {
 #'
 #' When the \code{authorize()} function is used the \code{GAToken} variable is created in the separate \code{TokenEnv} environment which is not visible for user. So, there is no need to pass the token argument to any function which requires authorization every time. Also there is a possibility to store token in separate variable and to pass it to the functions. It can be useful when you are working with several accounts at the same time.
 #'
+#' \code{username}, \code{client.id}, \code{client.secret} and \code{cache} params can be specified by an appropriate options (with \dQuote{rga} prefix).
+#'
 #' @section Use custom Client ID and Client secret:
 #'
 #' For some reasons you may need to use a custom client ID and client secret. In order to obtain these, you will have to register an application with the Google Analytics API. To find your project's client ID and client secret, do the following:
@@ -109,22 +119,35 @@ env_exists <- function(...) {
 #'
 #' @export
 #'
-authorize <- function(client.id = getOption("rga.client.id"),
+authorize <- function(username = getOption("rga.username"),
+                      client.id = getOption("rga.client.id"),
                       client.secret = getOption("rga.client.secret"),
                       cache = getOption("rga.cache"),
                       new.auth = FALSE) {
     if (all(env_exists("RGA_CLIENT_ID", "RGA_CLIENT_SECRET"))) {
-        message("client.id and client.secret loaded from environment variables.")
+        message("Client ID and Client secret loaded from environment variables.")
         client.id <- Sys.getenv("RGA_CLIENT_ID")
         client.secret <- Sys.getenv("RGA_CLIENT_SECRET")
     }
+    if (env_exists("RGA_USERNAME")) {
+        message("Username loaded from environment variable.")
+        username <- Sys.getenv("RGA_USERNAME")
+    }
+    app <- oauth_app(appname = "rga", key = client.id, secret = client.secret)
+    endpoint <- oauth_endpoints("google")
+    if (!is.null(username)) {
+        stopifnot(is.character(username))
+        stopifnot(length(username) == 1)
+        username <- fix_username(username)
+        endpoint$authorize <- paste0(endpoint$authorize, "?login_hint=", username)
+        cache <- paste0(".", username, "-token.rds")
+    }
     if (new.auth) {
         remove_token(getOption("rga.token"))
         if (is.character(cache))
             unlink(cache)
     }
-    rga_app <- oauth_app(appname = "rga", key = client.id, secret = client.secret)
-    token <- oauth2.0_token(endpoint = oauth_endpoints("google"), app = rga_app, cache = cache,
+    token <- oauth2.0_token(endpoint = endpoint, app = app, cache = cache,
                             scope = "https://www.googleapis.com/auth/analytics.readonly")
     set_token(getOption("rga.token"), token)
     invisible(token)
