@@ -2,7 +2,6 @@
 #' @include utils.R
 build_query <- function(...) {
     query <- list(...)
-    query <- compact(query)
     query <- fix_query(query)
     return(query)
 }
@@ -11,6 +10,7 @@ build_query <- function(...) {
 #' @include utils.R
 fix_query <- function(query) {
     stopifnot(is.list(query))
+    query <- compact(query)
     if (!grepl("^ga:", query$profile.id))
         query$profile.id <- paste0("ga:", query$profile.id)
     snames <- c("metrics", "dimensions", "sort")
@@ -21,7 +21,5 @@ fix_query <- function(query) {
     query[names(query) %in% dnames] <- lapply(query[names(query) %in% dnames], as.character)
     if (!is.empty(query$sampling.level))
         query$sampling.level <- toupper(query$sampling.level)
-    stopifnot(any(lapply(query, length) <= 1L))
-    stopifnot(all(vapply(query, is.vector, logical(1))))
     return(query)
 }
