@@ -1,3 +1,15 @@
+# Convert query list to the string
+#' @include utils.R
+prepare_query <- function(query) {
+    query <- compact(query)
+    params <- names(query)
+    params <- sub("profile.id", "ids", params, fixed = TRUE)
+    params <- sub("sampling.level", "samplingLevel", params, fixed = TRUE)
+    params <- gsub(".", "-", params, fixed = TRUE)
+    names(query) <- params
+    return(query)
+}
+
 # Error printing function
 #' @include utils.R
 #' @importFrom httr http_status
@@ -14,7 +26,7 @@ error_message <- function(x) {
 #' @title Get a Google Analytics API response
 #'
 #' @param type character string including report type.
-#' @param path list including a request parameters.
+#' @param path character including a request path.
 #' @param query list including a request parameters.
 #' @param simplify logical. Coerce JSON arrays to a vector, matrix or data frame.
 #' @param flatten logical. Automatically flatten nested data frames into a single non-nested data frame.
@@ -32,10 +44,10 @@ error_message <- function(x) {
 #' @importFrom httr GET config accept_json content
 #' @importFrom jsonlite fromJSON
 #'
-get_response <- function(type = c("ga", "rt", "mcf", "mgmt"), path = NULL, query = NULL,
+get_response <- function(type = c("ga", "realtime", "mcf", "mgmt"), path = NULL, query = NULL,
                          simplify = TRUE, flatten = TRUE, token) {
     type <- match.arg(type)
-    url <- get_url(type = type, path = path, query = query)
+    url <- get_url(type = type, path = path)
     if (missing(token) && token_exists(getOption("rga.token")))
         token <- get_token(getOption("rga.token"))
     if (!missing(token)) {
@@ -43,11 +55,14 @@ get_response <- function(type = c("ga", "rt", "mcf", "mgmt"), path = NULL, query
         config <- config(token = token)
     } else
         config <- NULL
-    resp <- GET(url, accept_json(), config)
+    if (!is.null(query) && is.list(query))
+        query <- prepare_query(query)
+    resp <- GET(url, query = query, accept_json(), config)
     if (resp$status_code == 401L) {
         authorize(cache = FALSE)
         return(eval(match.call()))
-    }
+    } else if (resp$status_code == 404L)
+        stop("The requested URL not found. URL: ", strsplit(resp$url, split = "?", fixed = TRUE)[[1]][1])
     data_json <- fromJSON(content(resp, as = "text"), simplifyVector = simplify, flatten = flatten)
     if (!is.null(data_json$error))
         error_message(data_json)
